#!/usr/bin/python

from edge import eventlog
from edge.com import fs
from edge.exceptions import *
from edge.webserver import cgi


# noinspection PyClassHasNoInit
class _ActionsApi:
    _DEF_UICONF_PATH = '/opt/edge/share/setupstore/ui/actions-jnode.json'
    _UICONF_PATH = '/etc/edge/setupstore/admin/actions/actions.json'

    @classmethod
    def _install_unit(cls):
        """
        :rtype: None
        """
        fs.create_jnode_from_default(cls._DEF_UICONF_PATH, cls._UICONF_PATH)

    @classmethod
    def load_unit(cls):
        """
        :rtype: dict
        """
        cls._install_unit()

        uiconf = fs.load_json3(cls._UICONF_PATH, default=None)
        if uiconf is None:
            eventlog.log_e('fail: InternalError')
            raise InternalError

        return uiconf


class _Module(cgi.CgiModule):
    """
    GET   /api/v2/sys/conf   /
    """
    def __init__(self, handler):
        """
        :type handler: () -> cgi.CgiReply
        """
        cgi.CgiModule.__init__(self, handler)

    @classmethod
    def factory(cls, request):
        """
        :type request: cgi.CgiRequest
        :rtype: cgi.CgiModule
        """
        method_to_handlers_map = {
            'GET': [
                cls._actions__get
            ]
        }

        handlers = method_to_handlers_map.get(request.method, [])
        for handler in handlers:
            try:
                return handler(request)

            except cgi.CgiError404:
                pass

        eventlog.log_d('fail: http404')
        raise cgi.CgiError404

    @classmethod
    def _actions__get(cls, request):
        """
        :type request: cgi.CgiRequest
        :rtype: cgi.CgiModule
        """
        if len(request.path_info) != 0:
            raise cgi.CgiError404

        request.assert_query_absent()
        request.assert_body_absent()

        def handler():
            """
            :rtype: cgi.CgiReply
            """
            uiconf = _ActionsApi.load_unit()
            return cgi.CgiReply.create200(uiconf)

        return cls(handler)


if __name__ == '__main__':
    eventlog.open_log('cgi-actions', 'debug')
    try:
        cgi.run_cgi(_Module.factory)
    finally:
        eventlog.close_log()
